@@ -13,11 +13,11 @@ __docformat__ = 'restructuredtext'
 import re
 import textwrap
 import argparse
-from inspect import getargspec
+from datalad.utils import getargspec
 
 from .constraints import expand_constraint_spec
 
-_whitespace_re = re.compile('\n\s+|^\s+')
+_whitespace_re = re.compile(r'\n\s+|^\s+')
 
 
 class Parameter(object):
